summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/addexistingfilesdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/autotools/addexistingfilesdlg.cpp')
-rw-r--r--buildtools/autotools/addexistingfilesdlg.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/buildtools/autotools/addexistingfilesdlg.cpp b/buildtools/autotools/addexistingfilesdlg.cpp
index 6d3224df..519acb33 100644
--- a/buildtools/autotools/addexistingfilesdlg.cpp
+++ b/buildtools/autotools/addexistingfilesdlg.cpp
@@ -49,15 +49,15 @@
#include "addexistingfilesdlg.h"
/*
* Constructs a AddExistingFilesDialog which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-AddExistingFilesDialog::AddExistingFilesDialog ( AutoProjectPart* part, AutoProjectWidget *widget, SubprojectItem* spitem, TargetItem* titem, TQWidget* parent, const char* name, bool modal, WFlags fl )
- : AddExistingDlgBase ( parent, name, modal, fl )
+AddExistingFilesDialog::AddExistingFilesDialog ( AutoProjectPart* part, AutoProjectWidget *widget, SubprojectItem* spitem, TargetItem* titem, TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : AddExistingDlgBase ( tqparent, name, modal, fl )
{
m_spitem = spitem;
m_titem = titem;
@@ -110,7 +110,7 @@ AddExistingFilesDialog::AddExistingFilesDialog ( AutoProjectPart* part, AutoProj
*/
AddExistingFilesDialog::~AddExistingFilesDialog()
{
- // no need to delete child widgets, Qt does it all for me
+ // no need to delete child widgets, TQt does it all for me
}
@@ -234,7 +234,7 @@ void AddExistingFilesDialog::slotOk()
progressBar->show();
progressBar->setFormat ( i18n ( "Importing... %p%" ) );
- qApp->processEvents();
+ tqApp->processEvents();
KFileItemListIterator items ( *importView->items() );
@@ -49,15 +49,15 @@
#include "addexistingfilesdlg.h"
/*
- * Constructs a AddExistingFilesDialog which is a child of 'parent', with the
+ * Constructs a AddExistingFilesDialog which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*